==> haskell-arch-web-0.2-175-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.2
visibility:           public
id:                   arch-web-0.2-GWukV7lmF7kBabkztXaOOc
key:                  arch-web-0.2-GWukV7lmF7kBabkztXaOOc
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  dd4502c297f543218cba489731125a23
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.2-GWukV7lmF7kBabkztXaOOc
depends:
    aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3 base-4.17.2.1
    deriving-aeson-0.2.10-LeeLOTd2diuD8sF4A6Tjb1 exceptions-0.10.5
    http-client-0.7.17-2bmcHc0cHmODspv0lmZ3j1
    http-client-tls-0.3.6.3-4HJGt4uiE0c6Cw9rBFFelB
    http-types-0.12.4-cGP4COhpCbDmQiO5iBXAE
    lens-5.2.3-I3BlAHfqsGAEvCz93DUGGV mtl-2.2.2
    servant-0.20.2-xDFEFHYsSQ9EzHuLtjJWH
    servant-client-0.20-7BIOqv7tpug22z2BgqN87T
    servant-client-core-0.20.2-F3sJBzOby3Z4ArNc7pQyuu text-2.0.2
    time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arch-web-0.2-176-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.2
visibility:           public
id:                   arch-web-0.2-IJE3zNitj0HJKdCiuFJKkl
key:                  arch-web-0.2-IJE3zNitj0HJKdCiuFJKkl
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  698f510166605d43e20fad490a287a23
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-web-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.2-IJE3zNitj0HJKdCiuFJKkl
depends:
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86 base-4.17.2.1
    deriving-aeson-0.2.10-DiLFCctW7x2GdbTEL4eEYL exceptions-0.10.5
    http-client-0.7.17-23w6wIj9GbeK9arRJvAmDK
    http-client-tls-0.3.6.3-2hSd1fCBdlWFtn05eObSxT
    http-types-0.12.4-D2DAVTmHvcDBQ0h7IvaEn9
    lens-5.2.3-JlyZXwZS00NBv5ScwlVipn mtl-2.2.2
    servant-0.20.2-Whv2R4jOvdDUQ6RhSkCpO
    servant-client-0.20-LAK8sD74dbm3Dj45RvlrpT
    servant-client-core-0.20.2-79BI2AywD62DfGMy7cX5nT text-2.0.2
    time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
